@@ -13,6 +13,10 @@ plot_abs_map <- function(variable,
                          output_format,
                          min_value,
                          max_value,
+                         lon_min,
+                         lon_max,
+                         lat_min,
+                         lat_max,
 						             color_pal,
 						             relative,
                          nbreaks,
@@ -74,6 +78,27 @@ plot_abs_map <- function(variable,
 
   date_format_string <- ifelse(language == "deu", "%d.%m.%Y", "%Y-%m-%d")
   date_format_string_short <- ifelse(language == "deu", "%d.%m.", "%m-%d")
+  
+  # Functions to calculate aspect ratio (code parts from ggplot2)
+  map_aspect = function(x, y) {
+    x.center <- sum(range(x)) / 2
+    y.center <- sum(range(y)) / 2
+    x.dist <- dist_central_angle(x.center + c(-0.5, 0.5), rep(y.center, 2))
+    y.dist <- dist_central_angle(rep(x.center, 2), y.center + c(-0.5, 0.5))
+    y.dist / x.dist
+  }
+  
+  dist_central_angle <- function(lon, lat) {
+    # Convert to radians
+    lat <- lat * pi / 180
+    lon <- lon * pi / 180
+    
+    hav <- function(x) sin(x / 2) ^ 2
+    ahav <- function(x) 2 * asin(x)
+    
+    n <- length(lat)
+    ahav(sqrt(hav(diff(lat)) + cos(lat[-n]) * cos(lat[-1]) * hav(diff(lon))))
+  }
 
   # input
   if (!is.null(nc)) opennc <- nc
@@ -85,6 +110,13 @@ plot_abs_map <- function(variable,
   
   nx <- length(lon)
   ny <- length(lat)
+  
+  if (is.null(lon_min)) {
+    lon_min <- min(lon, na.rm =TRUE)
+    lat_min <- min(lat, na.rm =TRUE)
+    lon_max <- max(lon, na.rm =TRUE)
+    lat_max <- max(lat, na.rm =TRUE)
+  }
 
   if (is_leap_year(year) && finish_doy > 60 && start_doy < 60) {
     # We remove the leap year date in this case so we actually have one day less.
@@ -104,10 +136,6 @@ plot_abs_map <- function(variable,
     field_for_setup_last <- field_source[, , duration]
   }
 
-
-  nx <- length(lon)
-  ny <- length(lat)
-
   # define colors
   bwr_col <-
     grDevices::colorRampPalette(
@@ -257,10 +285,17 @@ plot_abs_map <- function(variable,
   }
 
   coldiff <- max_value - min_value
-
+  
+  # Get aspect ratio
+  aspect_ratio <- map_aspect(c(lon_min, lon_max), c(lat_min, lat_max))
+   
   # pic size
-  pic.width <-  710
   pic.height <- 830
+  pic.width <-  round((((nx / ny) / aspect_ratio) * pic.height) * 1.09)
+  if (pic.width < 710) {
+    pic.width <- 830
+    pic.height <- round(pic.width * ((ny * aspect_ratio) / (nx * 1.09)))
+  }
 
   if (country_code == "TOT") {
     pic.width <-  830
@@ -296,13 +331,13 @@ plot_abs_map <- function(variable,
 
   # Size and location of the logo
   logo.size <- 0.26
-  logo.x <- 0.89
-  logo.y <- 0.04
+  logo.x <- 0.88
+  logo.y <- 0.06
 
   if (country_code == "EUR") {
     logo.size <- 0.16
-    logo.x <- 0.92
-    logo.y <- 0.04
+    logo.x <- 0.9
+    logo.y <- 0.06
   }
 
   logo_cmsaf_path <- system.file(
@@ -373,7 +408,7 @@ plot_abs_map <- function(variable,
     graphics::par(cex = 1.3,
                   mgp = c(2, 1, 0),
                   mar = c(2, 1, 3, 4) + 0.1)
-    fields::image.plot(
+    fields::imagePlot(
       lon,
       lat,
       field.plot_freeze,
@@ -388,7 +423,10 @@ plot_abs_map <- function(variable,
       nlevel = ncol - 1,
       axis.args = list(at = at.ticks, labels = names.ticks),
       legend.mar = lg_mar,
-      cex.main = 1.1
+      cex.main = 1.1,
+      xlim = c(lon_min, lon_max),
+      ylim = c(lat_min, lat_max),
+      asp = aspect_ratio
     )
 
     # State and/or country borders
@@ -447,7 +485,7 @@ plot_abs_map <- function(variable,
         paste0(box_text, climate_year_start, "-", climate_year_end)
       ), cex = 1.3)
     }
-    unit_location <- 0.918
+    unit_location <- 0.928
 
     if (country_code == "EUR") {
       unit_location <- 0.958
@@ -522,7 +560,7 @@ plot_abs_map <- function(variable,
             mar = c(2, 1, 3, 4) + 0.1
           )
 
-          fields::image.plot(
+          fields::imagePlot(
             lon,
             lat,
             field.plot_freeze,
@@ -537,7 +575,10 @@ plot_abs_map <- function(variable,
             nlevel = ncol - 1,
             legend.mar = lg_mar,
             axis.args = list(at = at.ticks, labels = names.ticks),
-            cex.main = 1.1
+            cex.main = 1.1,
+            xlim = c(lon_min, lon_max),
+            ylim = c(lat_min, lat_max),
+            asp = aspect_ratio
           )
 
           # State and/or country borders
@@ -614,7 +655,7 @@ plot_abs_map <- function(variable,
                              ),
                              cex = 1.3)
           }
-          unit_location <- 0.918
+          unit_location <- 0.928
 
           if (country_code == "EUR") {
             unit_location <- 0.958
@@ -669,7 +710,7 @@ plot_abs_map <- function(variable,
               mar = c(2, 1, 3, 4) + 0.1
             )
 
-            fields::image.plot(
+            fields::imagePlot(
               lon,
               lat,
               field.plot_freeze,
@@ -684,7 +725,10 @@ plot_abs_map <- function(variable,
               nlevel = ncol - 1,
               legend.mar = lg_mar,
               axis.args = list(at = at.ticks, labels = names.ticks),
-              cex.main = 1.1
+              cex.main = 1.1,
+              xlim = c(lon_min, lon_max),
+              ylim = c(lat_min, lat_max),
+              asp = aspect_ratio
             )
 
             # State and/or country borders
@@ -757,7 +801,7 @@ plot_abs_map <- function(variable,
                                ),
                                cex = 1.3)
             }
-            unit_location <- 0.918
+            unit_location <- 0.928
 
             if (country_code == "EUR") {
               unit_location <- 0.958
